#!/bin/bash
#
# artifactory-build-promotion pipe
#
# Required globals:
#   ARTIFACTORY_URL
#   ARTIFACTORY_USER
#   ARTIFACTORY_PASSWORD
#   TARGET_REPO
#   STATUS
#
# Optional globals:
#   COPY
#   JFROG_CLI_TEMP_DIR
#   JFROG_CLI_HOME_DIR
#   BUILD_NAME
#   EXTRA_ARGS
#

source "$(dirname "$0")/common.sh"

## Enable debug mode.
DEBUG_ARGS=
enable_debug() {
  if [[ "${DEBUG}" == "true" ]]; then
    info "Enabling debug mode."
    set -x
    DEBUG_ARGS="--verbose"
  fi
}

info "Starting pipe execution..."

# required parameters
ARTIFACTORY_URL=${ARTIFACTORY_URL:?'ARTIFACTORY_URL environment variable missing.'}
ARTIFACTORY_USER=${ARTIFACTORY_USER:?'ARTIFACTORY_USER environment variable missing.'}
ARTIFACTORY_PASSWORD=${ARTIFACTORY_PASSWORD:?'ARTIFACTORY_PASSWORD environment variable missing.'}
TARGET_REPO=${TARGET_REPO:?'TARGET_REPO environment variable missing.'}
STATUS=${STATUS:?'STATUS environment variable missing.'}

# optional parameters
BUILD_NAME=${BUILD_NAME:=$BITBUCKET_REPO_OWNER-$BITBUCKET_REPO_SLUG-$BITBUCKET_BRANCH}
JFROG_CLI_TEMP_DIR=${JFROG_CLI_TEMP_DIR:="."}
JFROG_CLI_HOME_DIR=${JFROG_CLI_HOME_DIR:="."}
COPY=${COPY:="true"}
EXTRA_ARGS=${EXTRA_ARGS:=""}
DEBUG=${DEBUG:="false"}

debug "build name is ${BUILD_NAME}"
debug "build number is ${BITBUCKET_BUILD_NUMBER}"

# Configure Artifactory instance with JFrog CLI
run jfrog rt config --url=$ARTIFACTORY_URL --user=$ARTIFACTORY_USER --password=$ARTIFACTORY_PASSWORD --interactive=false $EXTRA_ARGS

# Promote build
run jfrog rt bpr $BUILD_NAME $BITBUCKET_BUILD_NUMBER $TARGET_REPO --status=$STATUS --copy=$COPY $EXTRA_ARGS

if [[ "${status}" -eq 0 ]]; then
  success "Build \"$BUILD_NAME@$BITBUCKET_BUILD_NUMBER\" is promoted successfully. URL: $ARTIFACTORY_URL/webapp/$BUILD_NAME/$BITBUCKET_BUILD_NUMBER"
else
  fail "Failed to promote Build \"$BUILD_NAME@$BITBUCKET_BUILD_NUMBER\"."
fi
